==> ann-0.3.tar.gz: ann-0.3/include/ann_log_lazy.h <==
/***************************************************************************
                          ann_log_lazy.h  -  description
                             -------------------
    begin                : pon kwi 14 2003
    copyright            : (C) 2003 by Bartosz Lis
    email                : bartoszl@ics.p.lodz.pl
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef __ANN_LOG_LAZY_H
#define __ANN_LOG_LAZY_H

#include <ctype.h>

#include <ann_log.h>

namespace ANN
{

  class Log_lazy;

  //                //
 // class Log_lazy //
//                //

  class Log_lazy : public Log_rec
  {
  private:
    Log_lazy();

  protected:
    size_t  epochs;

    virtual void  prop_prepare(size_t epoch);
    virtual void  prop_update(size_t epoch);
    virtual void  prop_finish(size_t epoch);
    virtual void  prop_finished(size_t epoch);

  public:
    Log_lazy(Log &orig_, size_t epochs_=20)
    : Log_rec(orig_), epochs(epochs_) {}
    virtual ~Log_lazy();

  };

} // namespace ANN

#endif /* __ANN_LOG_LAZY_H */

==> ann-0.4.tar.gz: ann-0.4/include/ann_log_lazy.h <==
/***************************************************************************
                          ann_log_lazy.h  -  description
                             -------------------
    begin                : pon kwi 14 2003
    copyright            : (C) 2003 by Bartosz Lis
    email                : bartoszl@ics.p.lodz.pl
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef __ANN_LOG_LAZY_H
#define __ANN_LOG_LAZY_H

#include <ctype.h>

#include <ann_log.h>

namespace ANN
{

  class Log_lazy;

  //                //
 // class Log_lazy //
//                //

  class Log_lazy : public Log_rec
  {
  private:
    Log_lazy();

  protected:
    size_t  epochs;

    virtual void  prop_open(size_t epoch);
    virtual void  prop_close(size_t epoch);
    virtual void  prop_conclude(size_t epoch);
    virtual void  prop_concluded(size_t epoch);

  public:
    Log_lazy(Log &orig_, size_t epochs_=20)
    : Log_rec(orig_), epochs(epochs_) {}
    virtual ~Log_lazy();

  };

} // namespace ANN

#endif /* __ANN_LOG_LAZY_H */
